@@ -9,6 +9,7 @@ from PyQtGuiLib.header import Qt,QPainter,QStyle,QSizePolicy,QEasingCurve
 
 if PYQT_VERSIONS == "PyQt5"  :
     FramelessWindowHint = Qt.FramelessWindowHint
+    WindowTransparentForInput = Qt.WindowTransparentForInput
     Window = Qt.Window
     WindingFill = Qt.WindingFill
     WindowStaysOnTopHint = Qt.WindowStaysOnTopHint
@@ -28,7 +29,9 @@ if PYQT_VERSIONS == "PyQt5"  :
     blue = Qt.blue
     white = Qt.white
     black = Qt.black
+    green = Qt.green
     gray = Qt.gray
+    yellow = Qt.yellow
     transparent = Qt.transparent
     Antialiasing = QPainter.Antialiasing
     SmoothPixmapTransform = QPainter.SmoothPixmapTransform
@@ -64,9 +67,10 @@ if PYQT_VERSIONS == "PyQt5"  :
 
 
 if PYQT_VERSIONS in ["PyQt6","PySide2","PySide6"]:
-    Window = Qt.WindowType.Window
-    WindingFill = Qt.WindowType.WindingFill
+    WindowTransparentForInput = Qt.WindowType.WindowTransparentForInput
     FramelessWindowHint = Qt.WindowType.FramelessWindowHint
+    Window = Qt.WindowType.Window
+    WindingFill = Qt.FillRule.WindingFill
     WindowStaysOnTopHint =Qt.WindowType.WindowStaysOnTopHint
     ArrowCursor = Qt.CursorShape.ArrowCursor
     SizeFDiagCursor = Qt.CursorShape.SizeFDiagCursor
@@ -83,8 +87,10 @@ if PYQT_VERSIONS in ["PyQt6","PySide2","PySide6"]:
     red = Qt.GlobalColor.red
     blue = Qt.GlobalColor.blue
     white = Qt.GlobalColor.white
+    green = Qt.GlobalColor.green
     black = Qt.GlobalColor.black
     gray = Qt.GlobalColor.gray
+    yellow = Qt.GlobalColor.yellow
     transparent = Qt.GlobalColor.transparent
     Antialiasing = QPainter.RenderHint.Antialiasing
     SmoothPixmapTransform = QPainter.RenderHint.SmoothPixmapTransform
